@@ -181,7 +181,7 @@ my $_get_value_or_values = sub {
 
    my $v = (is_arrayref $params and $name eq '-1') ? [ @{ $params } ]
          : (is_arrayref $params                  ) ? $params->[ $name ]
-         : (                        $name eq '-1') ? $params
+         : (                        $name eq '-1') ? { %{ $params } }
                                                    : $params->{ $name };
 
    return $_defined_or_throw->( $name, $v, $opts );
@@ -568,7 +568,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2016 Peter Flanigan. All rights reserved
+Copyright (c) 2017 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
